<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>Object</name>
    <message>
        <source>Duplicate scoped enum name</source>
        <translation>Дублирование имени перечисления</translation>
    </message>
    <message>
        <source>Duplicate signal name</source>
        <translation>Дублирование имени сигнала</translation>
    </message>
    <message>
        <source>Duplicate property name</source>
        <translation>Дублирование имени свойства</translation>
    </message>
    <message>
        <source>Property names cannot begin with an upper case letter</source>
        <translation>Имена свойств не могут начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Duplicate default property</source>
        <translation>Дублирование свойства по умолчанию</translation>
    </message>
    <message>
        <source>Duplicate alias name</source>
        <translation>Дублирование имени псевдонима</translation>
    </message>
    <message>
        <source>Alias names cannot begin with an upper case letter</source>
        <translation>Имена псевдонимов не могут начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Значение свойства задано несколько раз</translation>
    </message>
</context>
<context>
    <name>QInputMethod</name>
    <message>
        <source>InputMethod is an abstract class</source>
        <translation>InputMethod ― это абстрактный класс</translation>
    </message>
</context>
<context>
    <name>QQmlAbstractDelegateComponent</name>
    <message>
        <source>Cannot create instance of abstract class AbstractDelegateComponent.</source>
        <translation>Нельзя создавать экземпляры абстрактного класса AbstractDelegateComponent.</translation>
    </message>
</context>
<context>
    <name>QQmlAnonymousComponentResolver</name>
    <message>
        <source>Component objects cannot declare new functions.</source>
        <translation>Объекты Component не могут объявлять новые функции.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new properties.</source>
        <translation>Объекты Component не могут объявлять новые свойства.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new signals.</source>
        <translation>Объекты Component не могут объявлять новые сигналы.</translation>
    </message>
    <message>
        <source>Cannot create empty component specification</source>
        <translation>Невозможно создать пустую спецификацю компонента</translation>
    </message>
    <message>
        <source>Component elements may not contain properties other than id</source>
        <translation>Элементы Component не могут содержать свойств кроме id</translation>
    </message>
    <message>
        <source>Invalid component body specification</source>
        <translation>Некорректная спецификация тела компонента</translation>
    </message>
    <message>
        <source>id is not unique</source>
        <translation>id не уникален</translation>
    </message>
    <message>
        <source>Circular alias reference detected</source>
        <translation>Обнаружен псевдоним с циклической ссылкой</translation>
    </message>
    <message>
        <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
        <translation>Некорректная ссылка на псевдоним. Не удалось найти id «%1»</translation>
    </message>
    <message>
        <source>Invalid alias target location: %1</source>
        <translation>Некорректное размещение цели псевдонима: %1</translation>
    </message>
</context>
<context>
    <name>QQmlCodeGenerator</name>
    <message>
        <source>Property value set multiple times</source>
        <translation>Значение свойства задано несколько раз</translation>
    </message>
    <message>
        <source>Expected type name</source>
        <translation>Ожидается название типа</translation>
    </message>
    <message>
        <source>Scoped enum names must begin with an upper case letter</source>
        <translation>Имена перечислений должны начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Enum names must begin with an upper case letter</source>
        <translation>Имена перечислений должны начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Enum value must be an integer</source>
        <translation>Значение перечисления должно быть целым</translation>
    </message>
    <message>
        <source>Enum value out of range</source>
        <translation>Значение перечисления вне диапазона</translation>
    </message>
    <message>
        <source>Signal names cannot begin with an upper case letter</source>
        <translation>Имена сигналов не могут начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Illegal signal name</source>
        <translation>Недопустимое имя сигнала</translation>
    </message>
    <message>
        <source>No property alias location</source>
        <translation>Отсутствует размещение псевдонима свойства</translation>
    </message>
    <message>
        <source>Invalid alias reference. An alias reference must be specified as &lt;id&gt;, &lt;id&gt;.&lt;property&gt; or &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</source>
        <translation>Некорректная ссылка на псевдоним. Ссылка на псевдоним должна быть указана, как &lt;id&gt;, &lt;id&gt;.&lt;свойство&gt; или &lt;id&gt;.&lt;свойство значения&gt;.&lt;свойство&gt;</translation>
    </message>
    <message>
        <source>Invalid alias location</source>
        <translation>Неверное размещение псевдонима</translation>
    </message>
    <message>
        <source>Invalid component id specification</source>
        <translation>Некорректная спецификация идентификатора компонента</translation>
    </message>
    <message>
        <source>Duplicate method name</source>
        <translation>Дублирование имени метода</translation>
    </message>
    <message>
        <source>Method names cannot begin with an upper case letter</source>
        <translation>Имена методов не могут начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Illegal method name</source>
        <translation>Недопустимое имя метода</translation>
    </message>
    <message>
        <source>Invalid empty ID</source>
        <translation>Пустой идентификатор недопустим</translation>
    </message>
    <message>
        <source>IDs cannot start with an uppercase letter</source>
        <translation>Идентификаторы не могут начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>IDs must start with a letter or underscore</source>
        <translation>Идентификаторы должны начинаться с буквы или подчёркивания</translation>
    </message>
    <message>
        <source>IDs must contain only letters, numbers, and underscores</source>
        <translation>Идентификаторы должны содержать только буквы, цифры и подчёркивания</translation>
    </message>
    <message>
        <source>ID illegally masks global JavaScript property</source>
        <translation>Недопустимо, чтобы идентификатор маскировал глобальное свойство JavaScript</translation>
    </message>
    <message>
        <source>Invalid use of id property</source>
        <translation>Некорректное использование свойства id</translation>
    </message>
    <message>
        <source>Illegal property name</source>
        <translation>Недопустимое имя свойства</translation>
    </message>
</context>
<context>
    <name>QQmlComponent</name>
    <message>
        <source>Invalid empty URL</source>
        <translation>Пустой URL недопустим</translation>
    </message>
    <message>
        <source>createObject: value is not an object</source>
        <translation>createObject: значение не является объектом</translation>
    </message>
    <message>
        <source>Object or context destroyed during incubation</source>
        <translation>Объект или контекст уничтожен во время инкубации</translation>
    </message>
</context>
<context>
    <name>QQmlConnections</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Невозможно назначить несуществующему свойству «%1»</translation>
    </message>
    <message>
        <source>Connections: nested objects not allowed</source>
        <translation>Подключения: вложенные объекты недопустимы</translation>
    </message>
    <message>
        <source>Connections: syntax error</source>
        <translation>Подключения: синтаксическая ошибка</translation>
    </message>
    <message>
        <source>Connections: script expected</source>
        <translation>Подключения: ожидается сценарий</translation>
    </message>
    <message>
        <source>Implicitly defined onFoo properties in Connections are deprecated. Use this syntax instead: function onFoo(&lt;arguments&gt;) { ... }</source>
        <translation>Явное определение свойств onFoo в Connections устарело. Используйте следующую форму: function onFoo(&lt;параметры&gt;) { ... }</translation>
    </message>
    <message>
        <source>Detected function &quot;%1&quot; in Connections element. This is probably intended to be a signal handler but no signal of the target matches the name.</source>
        <translation>Функция «%1» устарела в элементе Connections. Вероятно, он предназначен для обработки сигналов, но ни один из сигналов цели не соответствует имени.</translation>
    </message>
</context>
<context>
    <name>QQmlDebugServerImpl</name>
    <message>
        <source>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</source>
        <translation>Отладчик QML: Обнаружен неверный параметр «%1». Пропускается.</translation>
    </message>
    <message>
        <source>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</source>
        <translation>Отладчик QML: Пропускается «-qmljsdebugger=%1».</translation>
    </message>
    <message>
        <source>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</source>
        <translation>Формат: -qmljsdebugger=[file:&lt;файл&gt;|port:&lt;начальный_порт&gt;][,&lt;конечный_порт&gt;][,host:&lt;ip адрес&gt;][,блок][,services:&lt;сервис&gt;][,&lt;сервис&gt;]*</translation>
    </message>
    <message>
        <source>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</source>
        <translation>«file:» может использоваться для указания имени файла, к которому отладчик попытается подключиться с помощью QLocalSocket. Если передан параметр «file:», то «host:» и «port:» будут проигнорированы.</translation>
    </message>
    <message>
        <source>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</source>
        <translation>«host:» и «port:» могут использоваться для задания адреса и одного или диапазона портов, к которым отладчик попытается подключиться через QTcpServer.</translation>
    </message>
    <message>
        <source>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</source>
        <translation>«block» заставляет отладчик и некоторые сервисы ждать подключения и готовности клиентов перед первым запуском движка QML.</translation>
    </message>
    <message>
        <source>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</source>
        <translation>«services:» используется для задания списка отладочных сервисов, загружаемых отладчиком. Некоторые из них могут конфликтовать с другими. Отладчик V4 не должен загружаться при использовании профайлера QML, так как последний отключает JIT в пользу интерпретатора JavaScript. Следующие сервисы доступны по умолчанию:</translation>
    </message>
    <message>
        <source>The QML debugger</source>
        <translation>Отладчик QML</translation>
    </message>
    <message>
        <source>The V4 debugger</source>
        <translation>Отладчик V4</translation>
    </message>
    <message>
        <source>The QML inspector</source>
        <translation>Инспектор QML</translation>
    </message>
    <message>
        <source>The QML profiler</source>
        <translation>Профайлер QML</translation>
    </message>
    <message>
        <source>Allows the client to delay the starting and stopping of
		  QML engines until other services are ready. QtCreator
		  uses this service with the QML profiler in order to
		  profile multiple QML engines at the same time.</source>
        <translation>Позволяет клиентам задерживать запуск и остановку
		  движков QML, пока остальные сервисы не будут готовы. QtCreator
		  использует этот сервис совместно с профайлером QML для
		  одновременного профилирования нескольких движков QML.</translation>
    </message>
    <message>
        <source>Sends qDebug() and similar messages over the QML debug
		  connection. QtCreator uses this for showing debug
		  messages in the debugger console.</source>
        <translation>Отправляет qDebug() и прочие сообщения через отладочное соединение
		  QML. QtCreator использует его для отображения
		  отладочных сообщений в консоли отладчика.</translation>
    </message>
    <message>
        <source>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</source>
        <translation>Другие сервисы, предоставляемые модулями qmltooling, реализующими QQmlDebugServiceFactory и находящимися в стандартных каталогах модулей, также будут доступны и могут быть указаны. Если параметр «services» не указан, то будут загружены все найденные сервисы.</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModel</name>
    <message>
        <source>The delegate of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>Делегат DelegateModel нельзя менять внутри onUpdated.</translation>
    </message>
    <message>
        <source>The maximum number of supported DelegateModelGroups is 8</source>
        <translation>Поддерживается максимум 8 DelegateModelGroups</translation>
    </message>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Нельзя менять группу DelegateModel внутри onChanged</translation>
    </message>
    <message>
        <source>The delegates of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>Делегаты DelegateModel нельзя менять внутри onUpdated.</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModelGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation>Имена групп должны начинаться с маленькой буквы</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation>get: индекс вне диапазона</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation>insert: индекс вне диапазона</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation>create: индекс вне диапазона</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation>resolve: индекс from вне диапазона</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation>resolve: невереный индекс from</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation>resolve: индекс to вне диапазона</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation>resolve: невереный индекс to</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation>resolve: from не указывает на разрешённый элемент</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation>resolve: to ― не элемент модели</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation>remove: неверный индекс</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation>remove: индекс вне диапазона</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation>remove: неверное количество</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation>addGroups: индекс вне диапазона</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation>addGroups: неверное количество</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation>removeGroups: индекс вне диапазона</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation>removeGroups: неверное количество</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation>setGroups: индекс вне диапазона</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation>setGroups: неверное количество</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation>move: неверный индекс from</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation>move: неверный индекс to</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation>move: неверное количество</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation>move: индекс from вне диапазона</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation>move: индекс to вне диапазона</translation>
    </message>
</context>
<context>
    <name>QQmlEngine</name>
    <message>
        <source>Locale cannot be instantiated.  Use Qt.locale()</source>
        <translation>Нельзя создать локаль. Используйте Qt.locale()</translation>
    </message>
    <message>
        <source>Locale cannot be instantiated. Use Qt.locale()</source>
        <translation>Нельзя создать локаль. Используйте Qt.locale()</translation>
    </message>
    <message>
        <source>There are still &quot;%1&quot; items in the process of being created at engine destruction.</source>
        <translation>Ещё «%1» элементов будет создано в процессе при уничтожении движка.</translation>
    </message>
    <message>
        <source>executeSql called outside transaction()</source>
        <translation>executeSql() вызван вне transaction()</translation>
    </message>
    <message>
        <source>Read-only Transaction</source>
        <translation>Транзакция только для чтения</translation>
    </message>
    <message>
        <source>Version mismatch: expected %1, found %2</source>
        <translation>Несовпадение версий: ожидалась %1, найдена %2</translation>
    </message>
    <message>
        <source>SQL transaction failed</source>
        <translation>Не удалось выполнить транзакцию SQL</translation>
    </message>
    <message>
        <source>transaction: missing callback</source>
        <translation>транзакция: отсутствует обратный вызов</translation>
    </message>
    <message>
        <source>SQL: can&apos;t create database, offline storage is disabled.</source>
        <translation>SQL: нельзя создать базу данных ― автономное хранилище отключено.</translation>
    </message>
    <message>
        <source>LocalStorage: can&apos;t create path %1</source>
        <translation>LocalStorage: не удалось создать путь %1</translation>
    </message>
    <message>
        <source>SQL: database version mismatch</source>
        <translation>Не совпадает версия базы данных SQL</translation>
    </message>
</context>
<context>
    <name>QQmlEnumTypeResolver</name>
    <message>
        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
        <translation>Некорректное присваивание свойства: Значение перечисления «%1» не может начинаться с маленькой буквы</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Некорректное присваивание свойства: «%1» свойство только для чтения</translation>
    </message>
</context>
<context>
    <name>QQmlImportDatabase</name>
    <message>
        <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
        <translation>«%1» неоднозначно. Найдено в %2 и %3</translation>
    </message>
    <message>
        <source>- %1 is not a namespace</source>
        <translation>- %1 ― некорректное пространство имён</translation>
    </message>
    <message>
        <source>- nested namespaces not allowed</source>
        <translation>- вложенные пространства имён недопустимы</translation>
    </message>
    <message>
        <source>local directory</source>
        <translation>локальный каталог</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 and in %2</source>
        <translation>неоднозначно. Найдено в %1 и %2</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 in version %2.%3 and %4.%5</source>
        <translation>неоднозначно. Найдено в %1 версий %2.%3 и %4.%5</translation>
    </message>
    <message>
        <source>is instantiated recursively</source>
        <translation>обрабатывается рекурсивно</translation>
    </message>
    <message>
        <source>is not a type</source>
        <translation>не является типом</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; has no metadata URI</source>
        <translation>в статическом плагине «%2» модуля «%1» нет URI метаданных</translation>
    </message>
    <message>
        <source>module does not support the designer &quot;%1&quot;</source>
        <translation>модуль не поддерживает дизайнер «%1»</translation>
    </message>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation>не удалось загрузить плагин для модуля «%1»: %2</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; cannot be loaded: %3</source>
        <translation>невозможно загрузить статический плагин «%2» для модулья «%1»: %3</translation>
    </message>
    <message>
        <source>could not resolve all plugins for module &quot;%1&quot;</source>
        <translation>невозможно найти все плагины для модуля «%1»</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation>модуль «%1» плагина «%2» не найден</translation>
    </message>
    <message>
        <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
        <translation>«%1» версии %2.%3 определено более одного раза в модуле «%4»</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation>модуль «%1» версии %2.%3 не установлен</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>модуль «%1» не установлен</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation>«%1»: каталог не существует</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation>каталог «%1» не содержит ни qmldir, ни namespace</translation>
    </message>
    <message>
        <source>Module loaded for URI &apos;%1&apos; does not implement QQmlTypesExtensionInterface</source>
        <translation>Модуль загруженный для URI «%1» не реализует QQmlTypesExtensionInterface</translation>
    </message>
    <message>
        <source>File name case mismatch for &quot;%1&quot;</source>
        <translation>Регистр имени файла не соответствует «%1»</translation>
    </message>
    <message>
        <source>Module namespace &apos;%1&apos; does not match import URI &apos;%2&apos;</source>
        <translation>Пространство имён модуля «%1» не совпадает с импортируемым URI «%2»</translation>
    </message>
    <message>
        <source>Namespace &apos;%1&apos; has already been used for type registration</source>
        <translation>Пространство имён «%1» уже используется для регистрации типов</translation>
    </message>
    <message>
        <source>Module &apos;%1&apos; does not contain a module identifier directive - it cannot be protected from external registrations.</source>
        <translation>Модуль «%1» не содержит директивы определения модуля ― он не может быть защищён от внешних регистраций.</translation>
    </message>
</context>
<context>
    <name>QQmlListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty</source>
        <translation>не удалось включить динамические роли, так как эта модель не пуста</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty</source>
        <translation>не удалось включить статические роли, так как эта модель не пуста</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation>установка динамической роли должна выполняться из основного потока перед созданием каких-либо рабочих сценариев</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: индексы [%1 - %2] вне диапазона [0 - %3]</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation>remove: недопустимое число аргументов</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: индекс %1 вне диапазона</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation>insert: значение не является объектом</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: индекс вне диапазона</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation>append: значение не является объектом</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation>set: значение не является объектом</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation>set: индекс %1 вне диапазона</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation>ListElement: не может содержать вложенные элементы</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation>ListElement: невозможно использовать зарезервированное свойство «id»</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation>ListElement: невозможно использовать сценарий в качестве значения свойства</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation>ListModel: неопределённое свойство «%1»</translation>
    </message>
</context>
<context>
    <name>QQmlObjectCreator</name>
    <message>
        <source>Cannot assign value %1 to property %2</source>
        <translation>Невозможно присвоить значение «%1» свойству «%2»</translation>
    </message>
    <message>
        <source>Cannot set properties on %1 as it is null</source>
        <translation>Невозможно установить свойства для «%1», так как он нулевой</translation>
    </message>
    <message>
        <source>Cannot assign an object to signal property %1</source>
        <translation>Невозможно назначить объект к свойству сигнала %1</translation>
    </message>
    <message>
        <source>Cannot assign object type %1 with no default method</source>
        <translation>Невозможно присвоить объект типа «%1» без метода по умолчанию</translation>
    </message>
    <message>
        <source>Cannot connect mismatched signal/slot %1 %vs. %2</source>
        <translation>Невозможно подключить отсутствующий сигнал/слот %1 к %2</translation>
    </message>
    <message>
        <source>Cannot assign object to interface property</source>
        <translation>Невозможно назначить объект свойству интерфейса</translation>
    </message>
    <message>
        <source>Cannot assign object to read only list</source>
        <translation>Невозможно назначить объект только читаемому списку</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Невозможно назначить примитивы списку</translation>
    </message>
    <message>
        <source>Unable to create object of type %1</source>
        <translation>Невозможно создать объект типа «%1»</translation>
    </message>
    <message>
        <source>Composite Singleton Type %1 is not creatable</source>
        <translation>Нельзя создавать сложный Singleton-тип %1</translation>
    </message>
</context>
<context>
    <name>QQmlObjectModel</name>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: индекс %1 вне диапазона</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: индекс вне диапазона</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: индексы [%1 - %2] вне диапазона [0 - %3]</translation>
    </message>
</context>
<context>
    <name>QQmlParser</name>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation>Недопустимый синтаксис для экспоненциального числа</translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation>Незакрытый текст в конце строки</translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation>Недопустимая unicode esc-последовательность</translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation>Незаконченный литерал регулярного выражения</translation>
    </message>
    <message>
        <source>Invalid regular expression flag &apos;%0&apos;</source>
        <translation>Некорректный флаг «%0» в регулярном выражении</translation>
    </message>
    <message>
        <source>Unexpected token &apos;.&apos;</source>
        <translation>Неожиданный символ «.»</translation>
    </message>
    <message>
        <source>Stray newline in string literal</source>
        <translation>Ненужный перевод строки в строковом литерале</translation>
    </message>
    <message>
        <source>End of file reached at escape sequence</source>
        <translation>ESC-последовательность прервана концом файла</translation>
    </message>
    <message>
        <source>Illegal hexadecimal escape sequence</source>
        <translation>Недопустимая шестнадцатеричная esc-последовательность</translation>
    </message>
    <message>
        <source>Octal escape sequences are not allowed</source>
        <translation>Восьмеричные esc-последовательности недопустимы</translation>
    </message>
    <message>
        <source>At least one octal digit is required after &apos;0%1&apos;</source>
        <translation>Необходима минимум одна восьмеричная цифра после «0%1»</translation>
    </message>
    <message>
        <source>At least one binary digit is required after &apos;0%1&apos;</source>
        <translation>Необходима минимум одна двоичная цифра после «0%1»</translation>
    </message>
    <message>
        <source>Decimal numbers can&apos;t start with &apos;0&apos;</source>
        <translation>Десятичные числа не могут начинаться с «0»</translation>
    </message>
    <message>
        <source>At least one hexadecimal digit is required after &apos;0%1&apos;</source>
        <translation>Необходима минимум одна шестнадцатеричная цифра после «0%1»</translation>
    </message>
    <message>
        <source>Unterminated regular expression backslash sequence</source>
        <translation>Регулярное выражение содержит незавершённую экранированную последовательность</translation>
    </message>
    <message>
        <source>Unterminated regular expression class</source>
        <translation>Регулярное выражение содержит незавершённый класс</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Синтаксическая ошибка</translation>
    </message>
    <message>
        <source>Unexpected object definition</source>
        <translation>Неожиданное определение объекта</translation>
    </message>
    <message>
        <source>Invalid import qualifier ID</source>
        <translation>Некорректный ID спецификатора импорта</translation>
    </message>
    <message>
        <source>Reserved name &quot;Qt&quot; cannot be used as an qualifier</source>
        <translation>Зарезервированное имя «Qt» не может быть использовано в качестве спецификатора</translation>
    </message>
    <message>
        <source>Script import qualifiers must be unique.</source>
        <translation>Спецификаторы импорта сценария должны быть уникальными.</translation>
    </message>
    <message>
        <source>Script import requires a qualifier</source>
        <translation>Для импорта сценария требуется спецификатор</translation>
    </message>
    <message>
        <source>Library import requires a version</source>
        <translation>Импорт библиотеки требует версию</translation>
    </message>
    <message>
        <source>Pragma requires a valid qualifier</source>
        <translation>Pragma требует корректный квалификатор</translation>
    </message>
    <message>
        <source>Expected parameter type</source>
        <translation>Ожидается тип параметра</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: </source>
        <translation>Недопустимый тип параметра сигнала: </translation>
    </message>
    <message>
        <source>Invalid property type modifier</source>
        <translation>Недопустимый модификатор типа свойства</translation>
    </message>
    <message>
        <source>Unexpected property type modifier</source>
        <translation>Неожиданный модификатор типа свойства</translation>
    </message>
    <message>
        <source>Expected property type</source>
        <translation>Требуется тип свойства</translation>
    </message>
    <message>
        <source>JavaScript declaration outside Script element</source>
        <translation>Определение JavaScript вне элемента Script</translation>
    </message>
    <message>
        <source>Imported file must be a script</source>
        <translation>Импортируемый файл должен быть сценарием</translation>
    </message>
    <message>
        <source>Module import requires a minor version (missing dot)</source>
        <translation>При подключении модулей необходимо указывать минорную версию (отсутствует точка)</translation>
    </message>
    <message>
        <source>Module import requires a minor version (missing number)</source>
        <translation>При подключении модулей необходимо указывать минорную версию (отсутствует число)</translation>
    </message>
    <message>
        <source>File import requires a qualifier</source>
        <translation>Импортирование файла требует квалификатор</translation>
    </message>
    <message>
        <source>Invalid import qualifier</source>
        <translation>Некорректный квалификатор импортирования</translation>
    </message>
    <message>
        <source>Invalid module URI</source>
        <translation>Некорректный URI модуля</translation>
    </message>
    <message>
        <source>Module import requires a version</source>
        <translation>Для импортирования модуля необходима версия</translation>
    </message>
    <message>
        <source>Module import requires a qualifier</source>
        <translation>Для импортирования модуля необходим квалификатор</translation>
    </message>
</context>
<context>
    <name>QQmlPartsModel</name>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Нельзя менять группу DelegateModel внутри onChanged</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation>Компонент делегата должен быть типа Package.</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyCacheCreatorBase</name>
    <message>
        <source>Fully dynamic types cannot declare new properties.</source>
        <translation>Полностью динамические типы не могут объявлять новые свойства.</translation>
    </message>
    <message>
        <source>Fully dynamic types cannot declare new signals.</source>
        <translation>Полностью динамические типы не могут объявлять новые сигналы.</translation>
    </message>
    <message>
        <source>Fully Dynamic types cannot declare new functions.</source>
        <translation>Полностью динамические типы не могут объявлять новые функции.</translation>
    </message>
    <message>
        <source>Non-existent attached object</source>
        <translation>Несуществующий прикреплённый объект</translation>
    </message>
    <message>
        <source>Cannot override FINAL property</source>
        <translation>Невозможно переопределить свойство FINAL</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: %1</source>
        <translation>Недопустимый тип параметра сигнала: %1</translation>
    </message>
    <message>
        <source>Duplicate signal name: invalid override of property change signal or superclass signal</source>
        <translation>Повторяющееся имя сигнала: неправильная перегрузка сигнала для изменения свойства или сигнала из базового класса</translation>
    </message>
    <message>
        <source>Duplicate method name: invalid override of property change signal or superclass signal</source>
        <translation>Повторяющееся имя метода: неправильная перегрузка сигнала для изменения свойства или сигнала из базового класса</translation>
    </message>
    <message>
        <source>Invalid property type</source>
        <translation>Некорректный тип свойства</translation>
    </message>
    <message>
        <source>Cyclic alias</source>
        <translation>Зацикленный псевдоним</translation>
    </message>
    <message>
        <source>Invalid alias target</source>
        <translation>Неверная цель псевдонима</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyValidator</name>
    <message>
        <source>Property assignment expected</source>
        <translation>Требуется назначение свойства</translation>
    </message>
    <message>
        <source>Invalid use of namespace</source>
        <translation>Некорректное использование пространства имён</translation>
    </message>
    <message>
        <source>Invalid attached object assignment</source>
        <translation>Некорректное назначение прикреплённого объекта</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>«%1.%2» не доступно в %3 %4.%5.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>«%1.%2» не доступно из-за версии компоненты.</translation>
    </message>
    <message>
        <source>Cannot assign a value directly to a grouped property</source>
        <translation>Невозможно присвоить значение непосредственно сгруппированному свойству</translation>
    </message>
    <message>
        <source>Attached properties cannot be used here</source>
        <translation>Прикреплённые свойства не могут быть использованы здесь</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Некорректное присваивание свойства: «%1» свойство только для чтения</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a script property</source>
        <translation>Невозможно назначить множественное значение свойству сценария</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a singular property</source>
        <translation>Невозможно присвоить множество значений свойству, принимающему только одно</translation>
    </message>
    <message>
        <source>Property has already been assigned a value</source>
        <translation>Свойству уже назначено значение</translation>
    </message>
    <message>
        <source>Invalid grouped property access</source>
        <translation>Некорректный доступ к сгруппированному свойству</translation>
    </message>
    <message>
        <source>Invalid grouped property access: Property &quot;%1&quot; with primitive type &quot;%2&quot;.</source>
        <translation>Неверный доступ к групповому свойству: свойство «%1» примитивного типа «%2».</translation>
    </message>
    <message>
        <source>Invalid grouped property access: Property &quot;%1&quot; with type &quot;%2&quot;, which is not a value type</source>
        <translation>Неверный доступ к групповому свойству: свойство «%1» типа «%2», не являющегося значением</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent default property</source>
        <translation>Невозможно назначить несуществующему свойству по умолчанию</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Невозможно назначить несуществующему свойству «%1»</translation>
    </message>
    <message>
        <source>Invalid use of id property with a value type</source>
        <translation>Недопустимое использование свойства id с типом значения</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Невозможно назначить примитивы списку</translation>
    </message>
    <message>
        <source>Invalid property assignment: unknown enumeration</source>
        <translation>Некорректное присваивание свойства: неизвестное перечисление</translation>
    </message>
    <message>
        <source> - Assigning null to incompatible properties in QML is deprecated. This will become a compile error in future versions of Qt.</source>
        <translation> - Присваивание null несовместимым свойствам в QML устарело. Оно станет ошибкой компиляции в будущих версиях Qt.</translation>
    </message>
    <message>
        <source>Invalid property assignment: string expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «string»</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or string list expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «string» или «string list»</translation>
    </message>
    <message>
        <source>Invalid property assignment: byte array expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа массив «byte»</translation>
    </message>
    <message>
        <source>Invalid property assignment: url expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «url»</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsigned int expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «unsigned int»</translation>
    </message>
    <message>
        <source>Invalid property assignment: int expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «int»</translation>
    </message>
    <message>
        <source>Invalid property assignment: number expected</source>
        <translation>Некорректное присваивание свойства: требуется число</translation>
    </message>
    <message>
        <source>Invalid property assignment: color expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «color»</translation>
    </message>
    <message>
        <source>Invalid property assignment: date expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «date»</translation>
    </message>
    <message>
        <source>Invalid property assignment: time expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «time»</translation>
    </message>
    <message>
        <source>Invalid property assignment: datetime expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «datetime»</translation>
    </message>
    <message>
        <source>Invalid property assignment: point expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «point»</translation>
    </message>
    <message>
        <source>Invalid property assignment: size expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «size»</translation>
    </message>
    <message>
        <source>Invalid property assignment: rect expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «rect»</translation>
    </message>
    <message>
        <source>Invalid property assignment: boolean expected</source>
        <translation>Некорректное присваивание свойства: требуется значение булевого типа</translation>
    </message>
    <message>
        <source>Invalid property assignment: 2D vector expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «двухмерный вектор»</translation>
    </message>
    <message>
        <source>Invalid property assignment: 3D vector expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «трёхмерный вектор»</translation>
    </message>
    <message>
        <source>Invalid property assignment: 4D vector expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «четырёхмерный вектор»</translation>
    </message>
    <message>
        <source>Invalid property assignment: quaternion expected</source>
        <translation>Некорректное присваивание свойства: требуется кватернион</translation>
    </message>
    <message>
        <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
        <translation>Некорректное присваивание свойства: требуется регулярное выражение; используйте синтаксис /pattern/</translation>
    </message>
    <message>
        <source>Invalid property assignment: number or array of numbers expected</source>
        <translation>Некорректное присваивание свойства: требуется число или массив чисел</translation>
    </message>
    <message>
        <source>Invalid property assignment: int or array of ints expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «int» или массив «int»</translation>
    </message>
    <message>
        <source>Invalid property assignment: bool or array of bools expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «bool» или массив «bool»</translation>
    </message>
    <message>
        <source>Invalid property assignment: url or array of urls expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «url» или массив «url»</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or array of strings expected</source>
        <translation>Некорректное присваивание свойства: требуется значение типа «string» или массив «string»</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsupported type &quot;%1&quot;</source>
        <translation>Некорректное присваивание свойства: неподдерживаемый тип «%1»</translation>
    </message>
    <message>
        <source>&quot;%1&quot; cannot operate on &quot;%2&quot;</source>
        <translation>«%1» не может воздействовать на «%2»</translation>
    </message>
    <message>
        <source>Cannot assign object to list property &quot;%1&quot;</source>
        <translation>Невозможно присвоить объект свойству «%1» списка</translation>
    </message>
    <message>
        <source>Cannot assign value of type &quot;%1&quot; to property &quot;%2&quot;, expecting &quot;%3&quot;</source>
        <translation>Невозможно присвоить значение типа «%1» свойству «%2», требуется «%3»</translation>
    </message>
    <message>
        <source>Cannot assign value of type &quot;%1&quot; to property &quot;%2&quot;, expecting an object</source>
        <translation>Невозможно присвоить значение типа «%1» свойству «%2», требуется объект</translation>
    </message>
    <message>
        <source>Cannot assign to property of unknown type &quot;%1&quot;.</source>
        <translation>Невозможно присвоить свойству неизвестного типа «%1».</translation>
    </message>
    <message>
        <source>Unexpected object assignment for property &quot;%1&quot;</source>
        <translation>Неожиданное присваивание объекта для свойства «%1»</translation>
    </message>
    <message>
        <source>Cannot assign object of type &quot;%1&quot; to property of type &quot;%2&quot; as the former is neither the same as the latter nor a sub-class of it.</source>
        <translation>Нельзя назначить объект типа «%1» свойству типа «%2», так как тип первого не совпадает со вторым и не является его производным.</translation>
    </message>
    <message>
        <source>Invalid property assignment: script expected</source>
        <translation>Некорректное присваивание свойства: ожидается сценарий</translation>
    </message>
</context>
<context>
    <name>QQmlRewrite</name>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Сигнал использует неименованный параметр перед именованным.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Параметр сигнала «%1» скрывает глобальную переменную.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeData</name>
    <message>
        <source>Composite Singleton Type %1 is not creatable.</source>
        <translation>Нельзя создать сложный Singleton-тип %1.</translation>
    </message>
    <message>
        <source>Element is not creatable.</source>
        <translation>Элемент несоздаваем.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeLoader</name>
    <message>
        <source>Cannot update qmldir content for &apos;%1&apos;</source>
        <translation>Не удалось обновить содержимое qmldir для «%1»</translation>
    </message>
    <message>
        <source>No matching type found, pragma Singleton files cannot be used by QQmlComponent.</source>
        <translation>Подходящий тип не найден, файлы pragma Singleton не могут использоваться QQmlComponent.</translation>
    </message>
    <message>
        <source>pragma Singleton used with a non composite singleton type %1</source>
        <translation>pragma Singleton используется с несложным одиночным типом %1</translation>
    </message>
    <message>
        <source>Script %1 unavailable</source>
        <translation>Сценарий %1 недоступен</translation>
    </message>
    <message>
        <source>Type %1 unavailable</source>
        <translation>Тип «%1» недоступен</translation>
    </message>
    <message>
        <source>qmldir defines type as singleton, but no pragma Singleton found in type %1.</source>
        <translation>qmldir определяет тип как одиночный, но pragma Singleton не найдена в типе %1.</translation>
    </message>
    <message>
        <source>File was compiled ahead of time with an incompatible version of Qt and the original file cannot be found. Please recompile</source>
        <translation>Файл был предварительно собран с несовместимой версией Qt, а оригинальный файл найти не удалось. Пересоберите</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Нет такого файла или каталога</translation>
    </message>
    <message>
        <source>File is empty</source>
        <translation>Файл пуст</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>модуль «%1» не установлен</translation>
    </message>
    <message>
        <source>Namespace %1 cannot be used as a type</source>
        <translation>Пространство имён «%1» не может быть использовано в качестве типа</translation>
    </message>
    <message>
        <source>Unreported error adding script import to import database</source>
        <translation>Несообщённая ошибка добавления импорта сценария в БД импорта</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>QQuickAbstractAnimation</name>
    <message>
        <source>Cannot animate non-existent property &quot;%1&quot;</source>
        <translation>Невозможно анимировать несуществуещее свойство «%1»</translation>
    </message>
    <message>
        <source>Cannot animate read-only property &quot;%1&quot;</source>
        <translation>Невозможно анимировать свойство только для чтения «%1»</translation>
    </message>
    <message>
        <source>Animation is an abstract class</source>
        <translation>Animation ― это абстрактный класс</translation>
    </message>
    <message>
        <source>Animator is an abstract class</source>
        <translation>Animator ― это абстрактный класс</translation>
    </message>
</context>
<context>
    <name>QQuickAccessibleAttached</name>
    <message>
        <source>Accessible is only available via attached properties</source>
        <translation>Accessible доступна только через прикреплённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickAnchorAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Невозможно установить длительность &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickAnchors</name>
    <message>
        <source>Possible anchor loop detected on fill.</source>
        <translation>Обнаружена возможная цикличная привязка на fill.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on centerIn.</source>
        <translation>Обнаружена возможная цикличная привязка на centerIn.</translation>
    </message>
    <message>
        <source>Cannot anchor to an item that isn&apos;t a parent or sibling.</source>
        <translation>Невозможно установить привязку к элементу, не являющемуся родителем или соседом.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on vertical anchor.</source>
        <translation>Обнаружена возможная цикличная привязка к вертикальной привязке.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on horizontal anchor.</source>
        <translation>Обнаружена возможная цикличная привязка к горизонтальной привязке.</translation>
    </message>
    <message>
        <source>Cannot specify left, right, and horizontalCenter anchors at the same time.</source>
        <translation>Нельзя одновременно задавать верхнюю, нижнюю и среднюю по горизонтали привязки.</translation>
    </message>
    <message>
        <source>Cannot anchor to a null item.</source>
        <translation>Невозможно привязаться к нулевому элементу.</translation>
    </message>
    <message>
        <source>Cannot anchor a horizontal edge to a vertical edge.</source>
        <translation>Невозможно привязать горизонтальный край к вертикальному.</translation>
    </message>
    <message>
        <source>Cannot anchor item to self.</source>
        <translation>Невозможно привязать элемент к самому себе.</translation>
    </message>
    <message>
        <source>Cannot specify top, bottom, and verticalCenter anchors at the same time.</source>
        <translation>Нельзя одновременно задавать верхнюю, нижнюю и среднюю по вертикали привязки.</translation>
    </message>
    <message>
        <source>Baseline anchor cannot be used in conjunction with top, bottom, or verticalCenter anchors.</source>
        <translation>Нельзя использовать базовую привязку вместе с верхней, нижней и центральной по вертикали.</translation>
    </message>
    <message>
        <source>Cannot anchor a vertical edge to a horizontal edge.</source>
        <translation>Невозможно привязать вертикальный край к горизонтальному.</translation>
    </message>
</context>
<context>
    <name>QQuickAnimatedImage</name>
    <message>
        <source>Qt was built without support for QMovie</source>
        <translation>Qt было собрано без поддержки QMovie</translation>
    </message>
</context>
<context>
    <name>QQuickApplication</name>
    <message>
        <source>Application is an abstract class</source>
        <translation>Application ― это абстрактный класс</translation>
    </message>
</context>
<context>
    <name>QQuickBehavior</name>
    <message>
        <source>Cannot change the animation assigned to a Behavior.</source>
        <translation>Невозможно изменить анимацию, назначенную поведению.</translation>
    </message>
</context>
<context>
    <name>QQuickDragAttached</name>
    <message>
        <source>Drag is only available via attached properties</source>
        <translation>Drag доступна только через прикреплённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickDragHandler</name>
    <message>
        <source>DragAxis is only available as a grouped property of DragHandler</source>
        <translation>DragAxis доступен только как сгруппированное свойство DragHandler</translation>
    </message>
</context>
<context>
    <name>QQuickEnterKeyAttached</name>
    <message>
        <source>EnterKey attached property only works with Items</source>
        <translation>Подключённое свойство EnterKey работает только с элементами</translation>
    </message>
    <message>
        <source>EnterKey is only available via attached properties</source>
        <translation>EnterKey доступно только через подключённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickFlipable</name>
    <message>
        <source>front is a write-once property</source>
        <translation>front ― свойство для однократной записи</translation>
    </message>
    <message>
        <source>back is a write-once property</source>
        <translation>back ― свойство для однократной записи</translation>
    </message>
</context>
<context>
    <name>QQuickGraphicsInfo</name>
    <message>
        <source>GraphicsInfo is only available via attached properties</source>
        <translation>GraphicsInfo доступен только через подключаемые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickItemView</name>
    <message>
        <source>ItemView is an abstract base class</source>
        <translation>ItemView ― это абстрактный базовый класс</translation>
    </message>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат должен иметь тип Item</translation>
    </message>
</context>
<context>
    <name>QQuickKeyNavigationAttached</name>
    <message>
        <source>KeyNavigation is only available via attached properties</source>
        <translation>KeyNavigation доступна только через прикреплённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickKeysAttached</name>
    <message>
        <source>Keys is only available via attached properties</source>
        <translation>Keys доступны только через прикреплённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickLayoutMirroringAttached</name>
    <message>
        <source>LayoutMirroring is only available via attached properties</source>
        <translation>LayoutMirroring доступно только через подключаемые свойства</translation>
    </message>
    <message>
        <source>LayoutDirection attached property only works with Items and Windows</source>
        <translation>Подключённое свойство LayoutDirection работает только с элементами и окнами</translation>
    </message>
</context>
<context>
    <name>QQuickLoader</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation>setSource: значение не является объектом</translation>
    </message>
</context>
<context>
    <name>QQuickMouseEvent</name>
    <message>
        <source>GestureEvent is only available in the context of handling the gestureStarted signal from MultiPointTouchArea</source>
        <translation>GestureEvent доступен только в контексте обработки сигнала gestureStarted от MultiPointTouchArea</translation>
    </message>
    <message>
        <source>MouseEvent is only available within handlers in MouseArea</source>
        <translation>MouseEvent доступен только внутри обработчиков в MouseArea</translation>
    </message>
</context>
<context>
    <name>QQuickOpenGLInfo</name>
    <message>
        <source>OpenGLInfo is only available via attached properties</source>
        <translation>OpenGLInfo доступно только через подключаемые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickPaintedItem</name>
    <message>
        <source>Cannot create instance of abstract class PaintedItem</source>
        <translation>Нельзя создавать экземпляры абстрактного класса PaintedItem</translation>
    </message>
</context>
<context>
    <name>QQuickParentAnimation</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Невозможно сохранить внешний вид при сложном преобразовании</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Невозможно сохранить внешний вид при неоднородном масштабе</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Невозможно сохранить внешний вид при масштабе 0</translation>
    </message>
</context>
<context>
    <name>QQuickParentChange</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Невозможно сохранить внешний вид при сложном преобразовании</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Невозможно сохранить внешний вид при неоднородном масштабе</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Невозможно сохранить внешний вид при масштабе 0</translation>
    </message>
</context>
<context>
    <name>QQuickPathAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Невозможно установить длительность &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPathView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат должен быть типа Item</translation>
    </message>
</context>
<context>
    <name>QQuickPauseAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Невозможно установить длительность &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPixmap</name>
    <message>
        <source>Error decoding: %1: %2</source>
        <translation>Ошибка декодирования: %1: %2</translation>
    </message>
    <message>
        <source>Invalid image provider: %1</source>
        <translation>Недопустимый поставщик изображений: %1</translation>
    </message>
    <message>
        <source>Failed to get image from provider: %1</source>
        <translation>Не удалось получить изображение от поставщика: %1</translation>
    </message>
    <message>
        <source>Failed to get texture from provider: %1</source>
        <translation>Не удалось получить текстуру от поставщика: %1</translation>
    </message>
    <message>
        <source>Error decoding: %1</source>
        <translation>Ошибка декодирования: %1</translation>
    </message>
    <message>
        <source>Cannot open: %1</source>
        <translation>Не удалось открыть: %1</translation>
    </message>
</context>
<context>
    <name>QQuickPointerHandler</name>
    <message>
        <source>PointerEvent is only available as a parameter of several signals in PointerHandler</source>
        <translation>PointerEvent доступен только, как параметр ряда сигналов PointerHandler</translation>
    </message>
    <message>
        <source>PointerMouseEvent is only available as a parameter of several signals in PointerHandler</source>
        <translation>PointerMouseEvent доступен только как параметр нескольких сигналов в PointerHandler</translation>
    </message>
    <message>
        <source>PointerTouchEvent is only available as a parameter of several signals in PointerHandler</source>
        <translation>PointerTouchEvent доступен только как параметр нескольких сигналов в PointerHandler</translation>
    </message>
    <message>
        <source>EventPoint is only available as a member of PointerEvent</source>
        <translation>EventPoint доступен только, как член PointerEvent</translation>
    </message>
    <message>
        <source>EventTouchPoint is only available as a member of PointerEvent</source>
        <translation>EventTouchPoint доступен только, как член PointerEvent</translation>
    </message>
    <message>
        <source>PointerDevice is only available as a property of PointerEvent</source>
        <translation>PointerDevice доступен только, как свойство PointerEvent</translation>
    </message>
    <message>
        <source>PointerHandler is an abstract base class</source>
        <translation>PointerHandler — абстрактный базовый класс</translation>
    </message>
    <message>
        <source>ImageBase is an abstract base class</source>
        <translation>ImageBase ― это абстрактный класс</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Невозможно установить длительность &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyChanges</name>
    <message>
        <source>PropertyChanges does not support creating state-specific objects.</source>
        <translation>PropertyChanges не поддерживают создание объектов, зависимых от состояния.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Невозможно назначить несуществующему свойству «%1»</translation>
    </message>
    <message>
        <source>Cannot assign to read-only property &quot;%1&quot;</source>
        <translation>Невозможно назначить свойству только для чтения «%1»</translation>
    </message>
</context>
<context>
    <name>QQuickRepeater</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат должен быть типа Item</translation>
    </message>
</context>
<context>
    <name>QQuickShaderEffectMesh</name>
    <message>
        <source>Cannot create instance of abstract class ShaderEffectMesh.</source>
        <translation>Нельзя создавать экземпляры абстрактного класса ShaderEffectMesh.</translation>
    </message>
</context>
<context>
    <name>QQuickShapeGradient</name>
    <message>
        <source>ShapeGradient is an abstract base class</source>
        <translation>ShapeGradient ― это абстрактный базовый класс</translation>
    </message>
</context>
<context>
    <name>QQuickTextUtil</name>
    <message>
        <source>%1 does not support loading non-visual cursor delegates.</source>
        <translation>%1 не поддерживает загрузку невизуальных делегатов курсора.</translation>
    </message>
    <message>
        <source>Could not load cursor delegate</source>
        <translation>Не удалось загрузить делегат курсора</translation>
    </message>
</context>
<context>
    <name>QQuickTouchPoint</name>
    <message>
        <source>PointingDeviceUniqueId is only available via read-only properties</source>
        <translation>PointingDeviceUniqueId доступен только через только читаемые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickViewTransitionAttached</name>
    <message>
        <source>ViewTransition is only available via attached properties</source>
        <translation>ViewTransition доступна только через прикреплённые свойства</translation>
    </message>
</context>
<context>
    <name>QQuickWindow</name>
    <message>
        <source>Failed to create %1 context for format %2.
This is most likely caused by not having the necessary graphics drivers installed.

Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, make sure the ANGLE Open GL ES 2.0 emulation libraries (%3, %4 and d3dcompiler_*.dll) are available in the application executable&apos;s directory or in a location listed in PATH.</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format, ANGLE %3, %4 library names</extracomment>
        <translation>Не удалось создать контекст %1 для формата %2.
Это возможно из-за отсутствия необходимых графических драйверов в системе.

Установите драйвер обеспечивающий поддержку OpenGL версии от 2.0 и выше. Если это невозможно, убедитесь, что библиотеки эмуляции ANGLE Open GL ES 2.0 (%3, %4 и d3dcompiler_*.dll) находятся в каталоге с исполняемым файлом приложения или доступны в каталогах перечисленных в PATH.</translation>
    </message>
    <message>
        <source>Failed to create %1 context for format %2</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format specification</extracomment>
        <translation>Не удалось создать контекст %1 для формата %2</translation>
    </message>
</context>
<context>
    <name>QQuickWindowQmlImpl</name>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos; for Window &apos;%1&apos;</source>
        <translation>Свойства окна «%1» «visible» и «visibility» конфликтуют</translation>
    </message>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos;</source>
        <translation>Свойства «visible» и «visibility» конфликтуют</translation>
    </message>
</context>
<context>
    <name>SignalHandlerConverter</name>
    <message>
        <source>Non-existent attached object</source>
        <translation>Несуществующий прикреплённый объект</translation>
    </message>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Сигнал использует неименованный параметр перед именованным.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Параметр сигнала «%1» скрывает глобальную переменную.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>«%1.%2» не доступно в %3 %4.%5.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>«%1.%2» не доступно из-за версии компоненты.</translation>
    </message>
    <message>
        <source>Cannot assign a value to a signal (expecting a script to be run)</source>
        <translation>Невозможно назначить значение сигналу (сценарий должен быть запущен)</translation>
    </message>
    <message>
        <source>Incorrectly specified signal assignment</source>
        <translation>Неверно указано назначение сигнала</translation>
    </message>
</context>
<context>
    <name>SignalTransition</name>
    <message>
        <source>Specified signal does not exist.</source>
        <translation>Указанный сигнал отсутствует.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Невозможно назначить несуществующему свойству «%1»</translation>
    </message>
    <message>
        <source>SignalTransition: script expected</source>
        <translation>SignalTransition: ожидается сценарий</translation>
    </message>
</context>
<context>
    <name>qmlRegisterType</name>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;</source>
        <translation>Некорректное имя «%2» для QML %1</translation>
    </message>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;; type names must begin with an uppercase letter</source>
        <translation>Имя «%2» недопустимо для QML %1, имена типов должны начинаться с заглавной буквы</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected namespace &apos;%3&apos;</source>
        <translation>Нельзя устанавливать %1 «%2» в защищённое пространство имён «%3»</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected module &apos;%3&apos; version &apos;%4&apos;</source>
        <translation>Нельзя установить %1 «%2» в защищённый модуль «%3» версии «%4»</translation>
    </message>
</context>
</TS>
